@@ -69,6 +69,14 @@ has paste => (
     documentation => "If specified, use only the clipboard as input.",
 );
 
+has open_url => (
+    traits        => ['Getopt'],
+    is            => 'rw',
+    isa           => 'Bool',
+    cmd_aliases   => ['open', 'o'],
+    documentation => "If specified, automatically open the URL using Browser::Open.",
+);
+
 has quiet => (
     traits        => ['Getopt'],
     is            => 'rw',
@@ -119,6 +127,11 @@ sub run {
         Clipboard->copy($url);
     }
 
+    if ($self->open_url) {
+        require Browser::Open;
+        Browser::Open::open_browser($url);
+    }
+
     return $url;
 }
 
@@ -199,6 +212,11 @@ L<Clipboard> module.
 
 If specified, use only the clipboard as input, using the L<Clipboard> module.
 
+=head2 -o, --open
+
+If specified, automatically open the URL using L<Browser::Open>.  Browser::Open
+tries a number of different browser commands depending on your OS.
+
 =head2 -q, --quiet
 
 If specified, do not warn or complain about broken services.
